#include <i2c_t3.h>
#include <ArduinoPebbleSerial.h>

static const uint16_t SERVICE_ID = 0x1001;
static const uint16_t UPTIME_ATTRIBUTE_ID = 0x0002;
static const size_t UPTIME_ATTRIBUTE_LENGTH = 4;
static const uint16_t LAMP_ATTRIBUTE_ID = 0x0003;
static const size_t LAMP_ATTRIBUTE_LENGTH = 20;

static const uint16_t SERVICES[] = {SERVICE_ID};
static const uint8_t NUM_SERVICES = 1;

static const uint8_t PEBBLE_DATA_PIN = 1;
static uint8_t buffer[GET_PAYLOAD_BUFFER_SIZE(4)];

typedef struct __attribute__((packed)){
  uint8_t channel;
  uint8_t value;
} DMXP;

void setup() {
  pinMode(LED_BUILTIN, OUTPUT);
  Wire.begin();
#if defined(__MK20DX256__) || defined(__MK20DX128__)
  // Teensy 3.0/3.1 uses hardware serial mode (pins 0/1) with RX/TX shorted together
  ArduinoPebbleSerial::begin_hardware(buffer, sizeof(buffer), Baud57600, SERVICES, NUM_SERVICES);
#elif defined(__AVR_ATmega32U4__)
  // Teensy 2.0 uses the one-wire software serial mode
  ArduinoPebbleSerial::begin_software(PEBBLE_DATA_PIN, buffer, sizeof(buffer), Baud57600, SERVICES,
                                      NUM_SERVICES);
#else
#error "This example will only work for the Teensy 2.0, 3.0, or 3.1 boards"
#endif

for(int i = 1; i < 8; i++){
  sendChannel(i,0);
}

}

void handle_dmx_request(RequestType type, size_t length) {
  if (type != RequestTypeWrite) {
    return;
  }
  
  DMXP cmd = *(DMXP*)buffer;
  sendChannel(cmd.channel, cmd.value);
  
  // ACK that the write request was received
  ArduinoPebbleSerial::write(true, NULL, 0);
  ArduinoPebbleSerial::notify(SERVICE_ID, UPTIME_ATTRIBUTE_ID);
}

void loop() {
  if (ArduinoPebbleSerial::is_connected()) {
    digitalWrite(13,true);
  } else {
    digitalWrite(13,false);
  }

  uint16_t service_id;
  uint16_t attribute_id;
  size_t length;
  RequestType type;
  if (ArduinoPebbleSerial::feed(&service_id, &attribute_id, &length, &type)) {
    // process the request
    if (service_id == SERVICE_ID) {
      switch (attribute_id) {
        case LAMP_ATTRIBUTE_ID:
          handle_dmx_request(type, length);
          break;
        default:
          break;
      }
    }
  }
}

void sendChannel(int chan, int val){
  char chno[8];
  itoa(chan,chno,10);
  char vano[8];
  itoa(val,vano,10);
  char message[20];
  int messagei = 0;
  for(int i = 0; i < 7; i++){
    if(chno[i] == '\0'){
      break;
    }
    message[messagei++] = chno[i];
  }
  message[messagei++] = ':';
  for(int i = 0;i < 7; i++){
    if(vano[i] == '\0'){
      break;
    }
    message[messagei++] = vano[i];
  }
  message[messagei++] = '\n';
  message[messagei++] = '\r';
  message[messagei++] = '\0';
  Wire.beginTransmission(1);
  Wire.write(message);
  Wire.endTransmission();
}
